@@ -1,7 +1,6 @@
-from sqlalchemy import BIGINT, Column, String
-from notecoin.huobi.connection.impl import session
 import time
-from notecoin.database.base import Base, BaseTable
+
+from notecoin.database.base import Base, BaseTable, session
 from sqlalchemy import BIGINT, Column, Float, String
 
 
